﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace Sample
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            Map1.MapUnit = GeographyUnit.Meter;
            Loaded += MainWindow_Loaded;
        }

        private void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            if (File.Exists(@"..\..\Data\Southampton.shp"))
            {
                ShapeFileFeatureLayer shape = new ShapeFileFeatureLayer(@"..\..\Data\Southampton.shp");
                shape.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.City1;

                shape.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                shape.Open();
                Map1.CurrentExtent = shape.GetBoundingBox();
                shape.Close();

                LayerOverlay isoLineOverlay = new LayerOverlay();
                isoLineOverlay.Layers.Add("shp", shape);
                Map1.Overlays.Add("isoLineOverlay", isoLineOverlay);

                Map1.TrackOverlay = new TrackInteractiveOverlay();
                Map1.TrackOverlay.TrackMode = TrackMode.Polygon;
                Map1.TrackOverlay.TrackEnded += OnDragEnded;

                Map1.Refresh();
            }
        }

        private void OnDragEnded(object sender, TrackEndedTrackInteractiveOverlayEventArgs e)
        {
            var track = (TrackInteractiveOverlay)sender;
            if (!Map1.EditOverlay.EditShapesLayer.InternalFeatures.Any())
            {
                Map1.EditOverlay = new EditOverlay();
            }

            foreach (var feature in track.TrackShapeLayer.InternalFeatures)
            {
                Map1.EditOverlay.EditShapesLayer.InternalFeatures.Add(feature);
                Map1.EditOverlay.CalculateAllControlPoints();
            }
            track.TrackShapeLayer.InternalFeatures.Clear();
            Map1.Refresh(new Overlay[] { Map1.EditOverlay, Map1.TrackOverlay });
        }
    }

    internal class EditOverlay : EditInteractiveOverlay
    {
        public EditOverlay()
        {
            this.EditShapesLayer.ZoomLevelSet = GetZoomLevelSet();
        }

        public ZoomLevelSet GetZoomLevelSet()
        {
            ZoomLevelSet style = new ZoomLevelSet();

            style.ZoomLevel01.DefaultPointStyle = PointStyles.CreateSimplePointStyle(PointSymbolType.Circle, GeoColor.SimpleColors.Red, 4);
            style.ZoomLevel01.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.SimpleColors.Red, 1, false);
            style.ZoomLevel01.DefaultAreaStyle =
                AreaStyles.CreateSimpleAreaStyle(
                    GeoColor.FromArgb(20, new GeoColor(
                        GeoColor.SimpleColors.Red.AlphaComponent,
                        GeoColor.SimpleColors.Red.RedComponent,
                        GeoColor.SimpleColors.Red.GreenComponent,
                        GeoColor.SimpleColors.Red.BlueComponent)),
                    GeoColor.FromArgb(
                        GeoColor.SimpleColors.Red.AlphaComponent,
                        GeoColor.SimpleColors.Red.RedComponent,
                        GeoColor.SimpleColors.Red.GreenComponent,
                        GeoColor.SimpleColors.Red.BlueComponent));

            style.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            style.ZoomLevel01.DefaultTextStyle =
              new TextStyle("length", new GeoFont("Arial", 10, DrawingFontStyles.Bold), new GeoSolidBrush(GeoColor.SimpleColors.Black));
            style.ZoomLevel01.DefaultTextStyle.TextLineSegmentRatio = 100;
            style.ZoomLevel01.DefaultTextStyle.YOffsetInPixel = 10;

            style.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            return style;
        }
    }
}